
/* Generated data (by glib-mkenums) */

#ifndef __GWEATHER_ENUM_TYPES_H__
#define __GWEATHER_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "gweather-location.h" */
GType gweather_location_level_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_LOCATION_LEVEL (gweather_location_level_get_type ())

/* enumerations from "gweather-weather.h" */
GType gweather_provider_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_PROVIDER (gweather_provider_get_type ())
GType gweather_wind_direction_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_WIND_DIRECTION (gweather_wind_direction_get_type ())
GType gweather_sky_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_SKY (gweather_sky_get_type ())
GType gweather_phenomenon_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_PHENOMENON (gweather_phenomenon_get_type ())
GType gweather_qualifier_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_QUALIFIER (gweather_qualifier_get_type ())

/* enumerations from "gweather-enums.h" */
GType gweather_forecast_type_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_FORECAST_TYPE (gweather_forecast_type_get_type ())
GType gweather_temperature_unit_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_TEMPERATURE_UNIT (gweather_temperature_unit_get_type ())
GType gweather_speed_unit_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_SPEED_UNIT (gweather_speed_unit_get_type ())
GType gweather_pressure_unit_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_PRESSURE_UNIT (gweather_pressure_unit_get_type ())
GType gweather_distance_unit_get_type (void) G_GNUC_CONST;
#define GWEATHER_TYPE_DISTANCE_UNIT (gweather_distance_unit_get_type ())
G_END_DECLS

#endif /* __GWEATHER_ENUM_TYPES_H__ */

/* Generated data ends here */

